@@ -753,15 +753,16 @@ def modifyFilesNewGraph(version,group,name,type_graph,project_name):
     """
     errors = []
     primary_package = "springlabs_django"
+    SPRINGLABS_DJANGO_JSON = "springlabs_django.json"
     
 
     graph_version = version
     group_graph = group
     try:
-        with open('springlabs_django.json') as file:
+        with open(SPRINGLABS_DJANGO_JSON) as file:
             data = json.load(file)
     except:
-        message = "Ocurrió un problema interno al leer archivo (springlabs_django.json)"
+        message = f"Ocurrió un problema interno al leer archivo ({SPRINGLABS_DJANGO_JSON})"
         return message, False
     else:
         versions_detail = data['versions_detail']
@@ -786,8 +787,9 @@ def modifyFilesNewGraph(version,group,name,type_graph,project_name):
                             # Agregamos a lista de old_graphs los nombres de los graphs existentes
                             old_graphs.append(old_name)
     
+    example_django_name = f"ExampleDjango{group.capitalize()}"
     # Si se encuentra ExampleDjango en los graphs existentes
-    if "ExampleDjango" in old_graphs:
+    if example_django_name in old_graphs:
         delete_example = True 
     else:
         delete_example = False
@@ -832,7 +834,7 @@ def modifyFilesNewGraph(version,group,name,type_graph,project_name):
     find_query_api = find_query_api + ", graphene.ObjectType):"
     # Arma find de import schema.py e import api.py 
     for index, old_graph in enumerate(old_graphs):
-        if old_graph != "ExampleDjango":
+        if old_graph != example_django_name:
             old_graph_name = old_graph.capitalize()
         else:
             old_graph_name = old_graph
@@ -871,12 +873,12 @@ def modifyFilesNewGraph(version,group,name,type_graph,project_name):
             end="# END EXAMPLE GRAPHENE ObjectType (Managed by SPRINGLABS_DJANGO)")
         if result == False:
             errors.append([message, True])
-        
+        # Eliminar bandera START de ExampleDjango
         message, result = findNDelete(path=path,
             find="# EXAMPLE GRAPHENE ObjectType (Managed by SPRINGLABS_DJANGO)")
         if result == False:
             errors.append([message, True])
-        
+        # Eliminar bandera END de ExampleDjango
         message, result = findNDelete(path=path,
             find="# END EXAMPLE GRAPHENE ObjectType (Managed by SPRINGLABS_DJANGO)")
         if result == False:
@@ -889,12 +891,12 @@ def modifyFilesNewGraph(version,group,name,type_graph,project_name):
         counter = 0
         index_replace_example = 0
         for index, old_graph in enumerate(old_graphs_version):
-            if old_graph != "ExampleDjangoQueries":
+            if old_graph != f"{example_django_name}Queries":
                 if index == 0:
                     new_query_api = new_query_api+f"{old_graph}"
                 else:
                     new_query_api = new_query_api+f", {old_graph}"
-            elif old_graph == "ExampleDjangoQueries" and counter != 0:
+            elif old_graph == f"{example_django_name}Queries" and counter != 0:
                 if index == 0:
                     new_query_api = new_query_api+f"{old_graph}"
                 else:
@@ -907,7 +909,7 @@ def modifyFilesNewGraph(version,group,name,type_graph,project_name):
                 index_replace_example = index
                 counter = counter+1
         for index, old_graph in enumerate(old_graphs):
-            if old_graph != "ExampleDjango":
+            if old_graph != example_django_name:
                 if index == 0:
                     new_import_schema = new_import_schema+f" {old_graph.capitalize()}Type"
                     new_import_api = new_import_api+f" {old_graph.capitalize()}Queries"
@@ -916,10 +918,10 @@ def modifyFilesNewGraph(version,group,name,type_graph,project_name):
                     new_import_api = new_import_api+f", {old_graph.capitalize()}Queries"
         index_graph_example_django = False
         try:
-            with open('springlabs_django.json') as file:
+            with open(SPRINGLABS_DJANGO_JSON) as file:
                 data = json.load(file)
         except:
-            message = "Ocurrio un error interno al actualizar archivo springlabs_django.json"
+            message = f"Ocurrio un error interno al actualizar archivo {SPRINGLABS_DJANGO_JSON}"
             errors.append([message, True])
         else:
             versions_detail = data['versions_detail']
@@ -936,7 +938,7 @@ def modifyFilesNewGraph(version,group,name,type_graph,project_name):
                             graphs_json = group_detail['graph']
                             # Recorremos los graphs en la aplicación y grupo especificados
                             for index_graph, graph_json in enumerate(graphs_json):
-                                if graph_json['graph_name'] == "ExampleDjango":
+                                if graph_json['graph_name'] == example_django_name:
                                     index_graph_example_django = [index_versions,index_groups,index_graph]
             # Si existió graphQL en la lista de graphs de la versión y grupo
             if index_graph_example_django != False:
@@ -947,10 +949,10 @@ def modifyFilesNewGraph(version,group,name,type_graph,project_name):
                 data['versions_detail'][index_version]['graph_list'][index_replace_example] = f"{name.capitalize()}Queries"
                 data['versions_detail'][index_version]['groups_detail'][index_groups]['graph'].pop(index_graph)
             try:
-                with open("springlabs_django.json", "w") as file:
+                with open(SPRINGLABS_DJANGO_JSON, "w") as file:
                     file.write(json.dumps(data))
             except:
-                message = "Ocurrio un error interno al actualizar archivo springlabs_django.json"
+                message = f"Ocurrio un error interno al actualizar archivo {SPRINGLABS_DJANGO_JSON}"
                 errors.append([message, True])
     else:
         new_import_schema = find_import_schema + f", {name.capitalize()}Type"
@@ -958,18 +960,18 @@ def modifyFilesNewGraph(version,group,name,type_graph,project_name):
         new_query_api = base_new_query_api + f", {name.capitalize()}Queries"
         # Modifica graph_list
         try:
-            with open('springlabs_django.json') as file:
+            with open(SPRINGLABS_DJANGO_JSON) as file:
                 data = json.load(file)
         except:
-            message = "Ocurrio un error interno al actualizar archivo springlabs_django.json"
+            message = f"Ocurrio un error interno al actualizar archivo {SPRINGLABS_DJANGO_JSON}"
             errors.append([message, True])
         else:
             data['versions_detail'][index_version_modify]['graph_list'].append(f"{name.capitalize()}Queries")
             try:
-                with open("springlabs_django.json", "w") as file:
+                with open(SPRINGLABS_DJANGO_JSON, "w") as file:
                     file.write(json.dumps(data))
             except:
-                message = "Ocurrio un error interno al actualizar archivo springlabs_django.json"
+                message = f"Ocurrio un error interno al actualizar archivo {SPRINGLABS_DJANGO_JSON}"
                 errors.append([message, True])
         
         
@@ -1018,6 +1020,7 @@ def modifyFilesNewGroup(version, group,project_name):
     errors = []
     # Crear version en project_name/urls.py
     # Importar public versions de nueva versión
+    groupcap=group.capitalize()
     publicpath = f"api/v{version}/public_urls.py"
     privatepath = f"api/v{version}/private_urls.py"
     find = f"# v{version} PATTERNS (Managed by SPRINGLABS_DJANGO)"
@@ -1071,7 +1074,7 @@ def modifyFilesNewGroup(version, group,project_name):
     if result == False:
         errors.append([message, True])
 
-    content=f"from .{group}.schema import ExampleDjangoQueries"
+    content=f"from .{group}.schema import ExampleDjango{groupcap}Queries"
     path=f"graphql_api/v{version}/api.py"
     message, result = appendContent(path=path,
         content=content,
@@ -1100,7 +1103,8 @@ def modifyFilesNewGroup(version, group,project_name):
         for obj in version_data:
             content=content+obj+", "
         find=content+"graphene.ObjectType):"
-        content=content+"ExampleDjangoQueries, graphene.ObjectType):"
+
+        content=content+f"ExampleDjango{groupcap}Queries, graphene.ObjectType):"
         message, result=findNReplace(path, content, find)
         if result == False:
             errors.append([message, True])
@@ -1121,7 +1125,6 @@ def createDirectoriesNewGroup(version, group, project_name):
     os.chdir(f"api/v{version}")
     os.mkdir(group)
 
-
     base_serializers_py = "/core/new_version/api/baseSerializers.py"
     base_views_py = "/core/new_version/api/baseViews.py"
     
@@ -1150,12 +1153,15 @@ def createDirectoriesNewGroup(version, group, project_name):
 
     os.chdir(f"graphql_api/v{version}")
     os.mkdir(group)
-    base_schema_py = "/core/new_version/graphql_api/baseSchema.py"
-    base_types_py = "/core/new_version/graphql_api/baseTypes.py"
+    base_schema_py = "/core/new_group/graph/initial_schema.py"
+    base_types_py = "/core/new_group/graph/initial_type.py"
+    groupcap=group.capitalize()
+    changename=f"ExampleDjango{groupcap}"
 
     # Obtiene contenido de core/new_version/graphql_api/baseSchema.py
     try:
         template_schema_py = pkgutil.get_data(primary_package, base_schema_py).decode('utf-8')
+        template_schema_py = template_schema_py.replace("GRAPH_NAME", changename)
     except:
         message = f"Ocurrió un error interno en core/new_version/graphql_api/baseSchema.py"
         errors.append([message, True])
@@ -1163,6 +1169,7 @@ def createDirectoriesNewGroup(version, group, project_name):
     # Obtiene contenido de core/new_version/graphql_api/baseTypes.py
     try:
         template_types_py = pkgutil.get_data(primary_package, base_types_py).decode('utf-8')
+        template_types_py = template_types_py.replace("GRAPH_NAME", changename)
     except:
         message = f"Ocurrió un error interno en core/new_version/graphql_api/baseTypes.py"
         errors.append([message, True])
