@@ -65,14 +65,14 @@ def createVersion(version, project_name, old_versions):
         objVersionDetail = {
             "version": version,
             "groups": ["users"],
-            "graph_list":["ExampleDjangoQueries"],
+            "graph_list":["ExampleDjangoUsersQueries"],
             "groups_detail": [
                 {
                     "group": "users",
                     "apis": [],
                     "graph": [
                         {
-                            "graph_name": "ExampleDjango",
+                            "graph_name": "ExampleDjangoUsers",
                             "graph_type" : "open"
                         }
                     ]
@@ -295,10 +295,13 @@ def createGroup(version, group, project_name):
         message = "Ocurrio un error interno al actualizar archivo springlabs_django.json"
         errors.append([message, True])
     else:
+        groupcap=group.capitalize()
+        changename=f"ExampleDjango{groupcap}"
+
         objGroupDetail = {
                     "group": group,
                     "apis": [],
-                    "graph": [{"graph_name": "ExampleDjango",
+                    "graph": [{"graph_name": changename,
                     "graph_type": "open"}]
                 }
 
@@ -310,7 +313,7 @@ def createGroup(version, group, project_name):
                 obj["groups_detail"].append(objGroupDetail)
                 if not "graph_list" in obj:
                     obj["graph_list"]=[]
-                obj["graph_list"].append("ExampleDjangoQueries")
+                obj["graph_list"].append(f"{changename}Queries")
         try:
             with open("springlabs_django.json", "w") as file:
                 file.write(json.dumps(data))
