@@ -139,10 +139,13 @@ def validate_api_name_verb(ctx, param, value):
         Excepciones:
             click.BadParameter  [Raise] Mensaje de parámetro incorrecto
     """
-
-    api_version = ctx.params['version']
-    name_api = ctx.params['name']
-    group_api = ctx.params['group']
+    if "version" in ctx.params and "name" in ctx.params and "group" in ctx.params:
+        api_version = ctx.params['version']
+        name_api = ctx.params['name']
+        group_api = ctx.params['group']
+    else:
+        message = "Los parámetros están en orden incorrecto"
+        raise click.BadParameter(message)
     try:
         with open('springlabs_django.json') as file:
             data = json.load(file)
@@ -192,8 +195,11 @@ def validate_api_url(ctx, param, value):
         Excepciones:
             click.BadParameter  [Raise] Mensaje de parámetro incorrecto
     """
-
-    api_version = ctx.params['version']
+    if "version" in ctx.params:
+        api_version = ctx.params['version']
+    else:
+        message = "Los parámetros están en orden incorrecto"
+        raise click.BadParameter(message)
     # Validar que url no empiece en /
     if value.startswith("/") or value.endswith("/"):
         message = "La url no puede comenzar ni terminar con el caracter '/'"
@@ -262,9 +268,12 @@ def validate_graph_name(ctx, param, value):
     else:
         message = "The graph name must only contain letters and numbers (3-15 characters)"
         raise click.BadParameter(message)
-    
-    graph_version = ctx.params['version']
-    group_graph = ctx.params['group']
+    if "version" in ctx.params and "group" in ctx.params:
+        graph_version = ctx.params['version']
+        group_graph = ctx.params['group']
+    else:
+        message = "Los parámetros están en orden incorrecto"
+        raise click.BadParameter(message)
     name_graph = value
     try:
         with open('springlabs_django.json') as file:
@@ -305,7 +314,11 @@ def validate_group_group(ctx, param, value):
     message, result = validate_manage()
     if result == False:
         raise click.BadParameter(message)
-    insertversion=ctx.params["version"]
+    if "version" in ctx.params:
+        insertversion=ctx.params["version"]
+    else:
+        message = "Los parámetros están en orden incorrecto"
+        raise click.BadParameter(message)
 
     for detail in versions_detail:
         if detail["version"]==insertversion:
